summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/cppheadercodedocument.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenerators/cppheadercodedocument.cpp')
-rw-r--r--umbrello/umbrello/codegenerators/cppheadercodedocument.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/umbrello/umbrello/codegenerators/cppheadercodedocument.cpp b/umbrello/umbrello/codegenerators/cppheadercodedocument.cpp
index 2c471667..92bafba1 100644
--- a/umbrello/umbrello/codegenerators/cppheadercodedocument.cpp
+++ b/umbrello/umbrello/codegenerators/cppheadercodedocument.cpp
@@ -185,7 +185,7 @@ void CPPHeaderCodeDocument::loadChildTextBlocksFromNode ( TQDomElement & root)
} else
if( name == "codeoperation" ) {
// find the code operation by id
- TQString id = element.attribute("parent_id","-1");
+ TQString id = element.attribute("tqparent_id","-1");
UMLObject * obj = UMLApp::app()->getDocument()->findObjectById(STR2ID(id));
UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
if(op) {
@@ -206,7 +206,7 @@ void CPPHeaderCodeDocument::loadChildTextBlocksFromNode ( TQDomElement & root)
{
CPPHeaderClassDeclarationBlock * block = getClassDecl();
block->loadFromXMI(element);
- // normally this would be populated by the following syncToparent
+ // normally this would be populated by the following syncTotqparent
// call, but we cant wait for it, so lets just do it now.
namespaceBlock = getHierarchicalCodeBlock("namespace", "Namespace", 0);
@@ -326,7 +326,7 @@ void CPPHeaderCodeDocument::saveToXMI ( TQDomDocument & doc, TQDomElement & root
*/
// This method will cause the class to rebuild its text representation.
// based on the parent classifier object.
// For any situation in which this is called, we are either building the code
// document up, or replacing/regenerating the existing auto-generated parts. As
// such, we will want to insert everything we resonablely will want
@@ -334,7 +334,7 @@ void CPPHeaderCodeDocument::saveToXMI ( TQDomDocument & doc, TQDomElement & root
// comments) to appear or not, as needed.
void CPPHeaderCodeDocument::updateContent( )
{
// Gather info on the various fields and parent objects of this class...
UMLClassifier * c = getParentClassifier();
CodeGenPolicyExt *pe = UMLApp::app()->getPolicyExt();
CPPCodeGenerationPolicy * policy = dynamic_cast<CPPCodeGenerationPolicy*>(pe);
@@ -370,7 +370,7 @@ void CPPHeaderCodeDocument::updateContent( )
bool hasOperationMethods = c->getOpList().last() ? true : false;
bool hasNamespace = false;
bool isEnumeration = false;
- bool isInterface = parentIsInterface();
+ bool isInterface = tqparentIsInterface();
bool hasclassFields = hasClassFields();
bool forcedoc = UMLApp::app()->getCommonPolicy()->getCodeVerboseDocumentComments();
TQString endLine = UMLApp::app()->getCommonPolicy()->getNewLineEndingChars();
@@ -412,14 +412,14 @@ void CPPHeaderCodeDocument::updateContent( )
CodeGenerator::findObjectsRelated(c,includes);
for(UMLPackage *con = includes.first(); con ; con = includes.next())
- if (con->getBaseType() != Uml::ot_Datatype && !packageMap.contains(con))
+ if (con->getBaseType() != Uml::ot_Datatype && !packageMap.tqcontains(con))
{
packageMap.insert(con,con->getPackage());
if(con != getParentClassifier())
includeStatement.append("#include \""+CodeGenerator::cleanName(con->getName().lower())+".h\""+endLine);
}
// now, add/update the includes codeblock
- CodeBlockWithComments * inclBlock = addOrUpdateTaggedCodeBlockWithComments("includes", includeStatement, TQString::null, 0, false);
+ CodeBlockWithComments * inclBlock = addOrUpdateTaggedCodeBlockWithComments("includes", includeStatement, TQString(), 0, false);
if(includeStatement.isEmpty() && inclBlock->getContentType() == CodeBlock::AutoGenerated)
inclBlock->setWriteOutText(false);
else
@@ -800,7 +800,7 @@ void CPPHeaderCodeDocument::updateContent( )
// Operations
//
// nothing to do here.. "updateOperations" in parent class puts things
// in the right place using the "addCodeOperation" method we defined in this class
// FINISH up with hash def block close
@@ -326,7 +326,7 @@ void CPPHeaderCodeDocument::saveToXMI ( TQDomDocument & doc, TQDomElement & root
*/
// This method will cause the class to rebuild its text representation.
-// based on the parent classifier object.
+// based on the tqparent classifier object.
// For any situation in which this is called, we are either building the code
// document up, or replacing/regenerating the existing auto-generated parts. As
@@ -334,7 +334,7 @@ void CPPHeaderCodeDocument::saveToXMI ( TQDomDocument & doc, TQDomElement & root
void CPPHeaderCodeDocument::updateContent( )
{
- // Gather info on the various fields and parent objects of this class...
+ // Gather info on the various fields and tqparent objects of this class...
UMLClassifier * c = getParentClassifier();
CodeGenPolicyExt *pe = UMLApp::app()->getPolicyExt();
@@ -800,7 +800,7 @@ void CPPHeaderCodeDocument::updateContent( )
// Operations
//
- // nothing to do here.. "updateOperations" in parent class puts things
+ // nothing to do here.. "updateOperations" in tqparent class puts things
// in the right place using the "addCodeOperation" method we defined in this class
// FINISH up with hash def block close